@@ -4,8 +4,8 @@ import requests
 from inspect import currentframe as cf
 
 
-from src.bitpin.deprecated.exceptions import *
-from src.bitpin.enums import CurrenciesIDs, MarketsIDs
+from ..deprecated.exceptions import *
+from ..enums import CurrenciesIDs, MarketsIDs
 
 from logging import Logger
 
